==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/zh_TW.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU 資訊暫時無法使用",
    "CPU Usage:" : "CPU 使用量：",
    "Load average: {percentage} % ({load}) last minute" : "平均負載：{percentage} % ({load}) 前 1 分鐘",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) 前 1 分鐘\n{last5MinutesPercentage} % ({last5Minutes}) 前 5 分鐘\n{last15MinutesPercentage} % ({last15Minutes}) 前 15 分鐘",
    "RAM Usage:" : "RAM 使用量：",
    "SWAP Usage:" : "SWAP 使用量：",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM：總計 {memTotalBytes}／目前使用量：{memUsageBytes}",
    "RAM info not available" : "沒有可用的 RAM 資訊",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP：總計 {swapTotalBytes}／目前使用量：{swapUsageBytes}",
    "SWAP info not available" : "沒有可用的 SWAP 資訊",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按⌘-C以複製。",
    "Press Ctrl-C to copy." : "請按Ctrl-C以複製。",
    "System" : "系統",
    "Monitoring" : "監控",
    "Monitoring app with useful server information" : "使用有用的伺服器訊息以監控應用程式",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的伺服器訊息，例如CPU負載、記憶體使用情況、磁碟使用情況、用戶數等。",
    "Operating System:" : "作業系統：",
    "CPU:" : "CPU：",
    "Unknown Processor" : "未知的處理器",
    "Memory:" : "記憶體：",
    "Server time:" : "伺服器時間：",
    "Uptime:" : "運作時間：",
    "Temperature" : "氣溫",
    "Load" : "負載",
    "Memory" : "記憶體",
    "Disk" : "硬碟",
    "Mount:" : "掛載：",
    "Filesystem:" : "檔案系統：",
    "Size:" : "大小:",
    "Available:" : "可用：",
    "Used:" : "已使用：",
    "Files:" : "檔案:",
    "Storages:" : "儲存設備：",
    "Free Space:" : "可用空間：",
    "Network" : "網路",
    "Hostname:" : "主機名稱：",
    "Gateway:" : "網路閘道：",
    "Status:" : "狀態：",
    "Speed:" : "速度：",
    "Duplex:" : "雙工：",
    "MAC:" : "MAC：",
    "IPv4:" : "IPv4：",
    "IPv6:" : "IPv6：",
    "Active users" : "活動中的使用者",
    "Last hour" : "上個小時",
    "%s%% of all users" : "所有使用者的 %s%%",
    "Last 24 Hours" : "過去24小時",
    "Last 7 Days" : "過去7天",
    "Last 30 Days" : "過去30天",
    "Shares" : "分享",
    "Users:" : "使用者:",
    "Groups:" : "群組：",
    "Links:" : "連結：",
    "Emails:" : "電子郵件：",
    "Federated sent:" : "聯盟傳送：",
    "Federated received:" : "聯盟接收：",
    "Talk conversations:" : "Talk 對話：",
    "PHP" : "PHP",
    "Version:" : "版本:",
    "Memory limit:" : "記憶體限制：",
    "Max execution time:" : "最大執行時間：",
    "Upload max size:" : "上傳至多:",
    "OPcache Revalidate Frequency:" : "OPcache 重新驗證頻率：",
    "Extensions:" : "擴充套件：",
    "Unable to list extensions" : "無法列出擴充套件",
    "Show phpinfo" : "顯示 phpinfo",
    "FPM worker pool" : "FPM worker pool",
    "Pool name:" : "Pool 名稱：",
    "Pool type:" : "Pool 類型：",
    "Start time:" : "開始時間：",
    "Accepted connections:" : "接受的連線：",
    "Total processes:" : "總處理程序：",
    "Active processes:" : "作用中的處理程序：",
    "Idle processes:" : "閒置的處理程序：",
    "Listen queue:" : "監聽佇列：",
    "Slow requests:" : "慢請求：",
    "Max listen queue:" : "最大監聽佇列：",
    "Max active processes:" : "最大作用中處理程序：",
    "Max children reached:" : "最大子處理程序數：",
    "Database" : "資料庫",
    "Type:" : "類型:",
    "External monitoring tool" : "外部監控工具",
    "Use this end point to connect an external monitoring tool:" : "使用此端點連結外部監控工具：",
    "Copy" : "複製",
    "Output in JSON" : "以 JSON 輸出",
    "Skip apps section (including apps section will send an external request to the app store)" : "略過應用程式部份（包含應用程式部份將會向應用程式商店傳送外部請求）",
    "Skip server update" : "略過伺服器更新",
    "To use an access token, please generate one then set it using the following command:" : "要使用存取權杖，請產生一個，然後使用下列指令設定：",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "然後在查詢上面的 URL 時，將權杖與「NC-Token」標頭一起傳遞。",
    "Load average: {cpu} (last minute)" : "平均負載：{cpu}（前ㄧ分鐘）",
    "DNS:" : "DNS：",
    "Total users:" : "總使用者：",
    "24 hours:" : "24小時：",
    "1 hour:" : "1小時：",
    "5 mins:" : "5分鐘："
},
"nplurals=1; plural=0;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/zh_TW.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU 資訊暫時無法使用",
    "CPU Usage:" : "CPU 使用量：",
    "Load average: {percentage} % ({load}) last minute" : "平均負載：{percentage} % ({load}) 前 1 分鐘",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) 前 1 分鐘\n{last5MinutesPercentage} % ({last5Minutes}) 前 5 分鐘\n{last15MinutesPercentage} % ({last15Minutes}) 前 15 分鐘",
    "RAM Usage:" : "RAM 使用量：",
    "SWAP Usage:" : "SWAP 使用量：",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM：總計 {memTotalBytes}／目前使用量：{memUsageBytes}",
    "RAM info not available" : "沒有可用的 RAM 資訊",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP：總計 {swapTotalBytes}／目前使用量：{swapUsageBytes}",
    "SWAP info not available" : "沒有可用的 SWAP 資訊",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按⌘-C以複製。",
    "Press Ctrl-C to copy." : "請按Ctrl-C以複製。",
    "Unknown" : "未知",
    "%1$d days, %2$d hours, %3$d minutes, %4$d seconds" : "%1$d天%2$d小時%3$d分鐘%4$d秒",
    "%1$d hours, %2$d minutes, %3$d seconds" : "%1$d小時%2$d分鐘%3$d秒",
    "System" : "系統",
    "Monitoring" : "監控",
    "Monitoring app with useful server information" : "使用有用的伺服器訊息以監控應用程式",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的伺服器訊息，例如CPU負載、記憶體使用情況、磁碟使用情況、用戶數等。",
    "Operating System:" : "作業系統：",
    "CPU:" : "CPU：",
    "threads" : "執行緒",
    "Memory:" : "記憶體：",
    "Server time:" : "伺服器時間：",
    "Uptime:" : "運作時間：",
    "Temperature" : "氣溫",
    "Load" : "負載",
    "Memory" : "記憶體",
    "Disk" : "硬碟",
    "Mount:" : "掛載：",
    "Filesystem:" : "檔案系統：",
    "Size:" : "大小:",
    "Available:" : "可用：",
    "Used:" : "已使用：",
    "Files:" : "檔案:",
    "Storages:" : "儲存設備：",
    "Free Space:" : "可用空間：",
    "Network" : "網路",
    "Hostname:" : "主機名稱：",
    "Gateway:" : "網路閘道：",
    "Status:" : "狀態：",
    "Speed:" : "速度：",
    "Duplex:" : "雙工：",
    "MAC:" : "MAC：",
    "IPv4:" : "IPv4：",
    "IPv6:" : "IPv6：",
    "Active users" : "活動中的使用者",
    "Last hour" : "上個小時",
    "%s%% of all users" : "所有使用者的 %s%%",
    "Last 24 Hours" : "過去24小時",
    "Last 7 Days" : "過去7天",
    "Last 30 Days" : "過去30天",
    "Shares" : "分享",
    "Users:" : "使用者:",
    "Groups:" : "群組：",
    "Links:" : "連結：",
    "Emails:" : "電子郵件：",
    "Federated sent:" : "聯盟傳送：",
    "Federated received:" : "聯盟接收：",
    "Talk conversations:" : "Talk 對話：",
    "PHP" : "PHP",
    "Version:" : "版本:",
    "Memory limit:" : "記憶體限制：",
    "MB" : "MB",
    "Max execution time:" : "最大執行時間：",
    "seconds" : "秒",
    "Upload max size:" : "上傳至多:",
    "OPcache Revalidate Frequency:" : "OPcache 重新驗證頻率：",
    "Extensions:" : "擴充套件：",
    "Unable to list extensions" : "無法列出擴充套件",
    "PHP Info:" : "PHP 資訊：",
    "Show phpinfo" : "顯示 phpinfo",
    "FPM worker pool" : "FPM worker pool",
    "Pool name:" : "Pool 名稱：",
    "Pool type:" : "Pool 類型：",
    "Start time:" : "開始時間：",
    "Accepted connections:" : "接受的連線：",
    "Total processes:" : "總處理程序：",
    "Active processes:" : "作用中的處理程序：",
    "Idle processes:" : "閒置的處理程序：",
    "Listen queue:" : "監聽佇列：",
    "Slow requests:" : "慢請求：",
    "Max listen queue:" : "最大監聽佇列：",
    "Max active processes:" : "最大作用中處理程序：",
    "Max children reached:" : "最大子處理程序數：",
    "Database" : "資料庫",
    "Type:" : "類型:",
    "External monitoring tool" : "外部監控工具",
    "Use this end point to connect an external monitoring tool:" : "使用此端點連結外部監控工具：",
    "Copy" : "複製",
    "Output in JSON" : "以 JSON 輸出",
    "Skip apps section (including apps section will send an external request to the app store)" : "略過應用程式部份（包含應用程式部份將會向應用程式商店傳送外部請求）",
    "Skip server update" : "略過伺服器更新",
    "To use an access token, please generate one then set it using the following command:" : "要使用存取權杖，請產生一個，然後使用下列指令設定：",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "然後在查詢上面的 URL 時，將權杖與「NC-Token」標頭一起傳遞。",
    "Unknown Processor" : "未知的處理器"
},
"nplurals=1; plural=0;");
